//
//  WebViewController.m
//
//  Created by Thomas Tempelmann on 28.04.10.
//

#import "WebViewController.h"


@implementation WebViewController


- (UIWebView*)webView
{
	return (UIWebView *) self.view;
}

- (void)dealloc
{
	self.webView.delegate = nil;
	[self.webView stopLoading];
	[super dealloc];
}

- (void)viewDidLoad
{
	[super viewDidLoad];

	self.webView.delegate = self;

	// file based loading - this ignores the MIME Type we received from the server, though
	NSString *path = [[NSBundle mainBundle] pathForResource:@"sample" ofType:@"doc"];
	NSURLRequest *req = [NSURLRequest requestWithURL:[NSURL fileURLWithPath:path isDirectory:NO]];
	[self.webView loadRequest:req];
}

#pragma mark -
#pragma mark UIWebViewDelegate

- (BOOL)webView:(UIWebView *)webView shouldStartLoadWithRequest:(NSURLRequest *)request navigationType:(UIWebViewNavigationType)navigationType
{
	static char* navTypes[] = {"link","submit","back/forward","reload","resubmit","other"};
	NSLog(@"webView -- '%s' to %@", navTypes[navigationType], request.URL);
	return YES;
}

- (void)webViewDidStartLoad:(UIWebView *)webView
{
	NSLog(@"webView -- start rendering");

	[self.view addSubview:activityIndicator];
	activityIndicator.center = self.view.center;
	activityIndicator.hidden = NO;
	
	self.navigationItem.hidesBackButton = YES;
}

- (void)webViewDidFinishLoad:(UIWebView *)webView
{
	NSLog(@"webView -- finished rendering");

	activityIndicator.hidden = YES;
	[activityIndicator removeFromSuperview];

	self.navigationItem.hidesBackButton = NO;
}

- (void)webView:(UIWebView *)webView didFailLoadWithError:(NSError *)error
{
	NSLog(@"webView -- error: %@", error);

	activityIndicator.hidden = YES;
	[activityIndicator removeFromSuperview];

	self.navigationItem.hidesBackButton = NO;
}


@end
